@@ -1,10 +1,8 @@
 	// CommonJS, AMD, script tag
 	if (typeof exports !== "undefined") {
 		module.exports = filesize;
-	} else if (typeof define === "function" && define.amd) {
-		define(() => {
-			return filesize;
-		});
+	} else if (typeof define === "function" && define.amd !== void 0) {
+		define(() => filesize);
 	} else {
 		global.filesize = filesize;
 	}
